==> thunderbird_78.8.0.orig.tar.xz: thunderbird-78.8.0/devtools/client/debugger/src/components/test/WhyPaused.spec.js <==
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at <http://mozilla.org/MPL/2.0/>. */

// @flow

import React from "react";
import { shallow } from "enzyme";
import WhyPaused from "../SecondaryPanes/WhyPaused.js";

function render(why: Object, delay: ?number) {
  const props = { why, delay };

  // $FlowIgnore
  const component = shallow(<WhyPaused.WrappedComponent {...props} />);

  return { component, props };
}

describe("WhyPaused", () => {
  it("should pause reason with message", () => {
    const why = {
      type: "breakpoint",
      message: "bla is hit",
    };
    const { component } = render(why);
    expect(component).toMatchSnapshot();
  });

  it("should show pause reason with exception details", () => {
    const why = {
      type: "exception",
      exception: {
        class: "Error",
        preview: {
          name: "ReferenceError",
          message: "o is not defined",
        },
      },
    };

    const { component } = render(why);
    expect(component).toMatchSnapshot();
  });

  it("should show pause reason with exception string", () => {
    const why = {
      type: "exception",
      exception: "Not Available",
    };

    const { component } = render(why);
    expect(component).toMatchSnapshot();
  });

  it("should show an empty div when there is no pause reason", () => {
    const why = undefined;

    const { component } = render(why);
    expect(component).toMatchSnapshot();
  });
});

==> thunderbird_91.12.0.orig.tar.xz: thunderbird-91.12.0/devtools/client/debugger/src/components/test/WhyPaused.spec.js <==
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at <http://mozilla.org/MPL/2.0/>. */

import React from "react";
import { shallow } from "enzyme";
import WhyPaused from "../SecondaryPanes/WhyPaused.js";

function render(why, delay) {
  const props = { why, delay };

  const component = shallow(<WhyPaused.WrappedComponent {...props} />);

  return { component, props };
}

describe("WhyPaused", () => {
  it("should pause reason with message", () => {
    const why = {
      type: "breakpoint",
      message: "bla is hit",
    };
    const { component } = render(why);
    expect(component).toMatchSnapshot();
  });

  it("should show pause reason with exception details", () => {
    const why = {
      type: "exception",
      exception: {
        class: "ReferenceError",
        isError: true,
        preview: {
          name: "ReferenceError",
          message: "o is not defined",
        },
      },
    };

    const { component } = render(why);
    expect(component).toMatchSnapshot();
  });

  it("should show pause reason with exception string", () => {
    const why = {
      type: "exception",
      exception: "Not Available",
    };

    const { component } = render(why);
    expect(component).toMatchSnapshot();
  });

  it("should show an empty div when there is no pause reason", () => {
    const why = undefined;

    const { component } = render(why);
    expect(component).toMatchSnapshot();
  });
});
